Index: third_party/protobuf/src/google/protobuf/compiler/javanano/javanano_generator.h |
diff --git a/third_party/protobuf/src/google/protobuf/compiler/java/java_generator.h b/third_party/protobuf/src/google/protobuf/compiler/javanano/javanano_generator.h |
similarity index 75% |
copy from third_party/protobuf/src/google/protobuf/compiler/java/java_generator.h |
copy to third_party/protobuf/src/google/protobuf/compiler/javanano/javanano_generator.h |
index 888b8d85e929d3cab46ed24fe25ef24f906457b4..6f9f7f2a4a01d97cc3b5d0af5c50950065459a44 100644 |
--- a/third_party/protobuf/src/google/protobuf/compiler/java/java_generator.h |
+++ b/third_party/protobuf/src/google/protobuf/compiler/javanano/javanano_generator.h |
@@ -32,10 +32,10 @@ |
// Based on original Protocol Buffers design by |
// Sanjay Ghemawat, Jeff Dean, and others. |
// |
// Generates Java code for a given .proto file. |
#ifndef GOOGLE_PROTOBUF_COMPILER_JAVA_GENERATOR_H__ |
#define GOOGLE_PROTOBUF_COMPILER_JAVA_GENERATOR_H__ |
#include <string> |
#include <google/protobuf/compiler/code_generator.h> |
@@ -43,30 +43,30 @@ |
namespace google { |
namespace protobuf { |
namespace compiler { |
-namespace java { |
+namespace javanano { |
-// CodeGenerator implementation which generates Java code. If you create your |
-// own protocol compiler binary and you want it to support Java output, you |
-// can do so by registering an instance of this CodeGenerator with the |
-// CommandLineInterface in your main() function. |
-class LIBPROTOC_EXPORT JavaGenerator : public CodeGenerator { |
+// CodeGenerator implementation which generates Java nano code. If you create your |
+// own protocol compiler binary and you want it to support Java output for the |
+// nano runtime, you can do so by registering an instance of this CodeGenerator with |
+// the CommandLineInterface in your main() function. |
+class LIBPROTOC_EXPORT JavaNanoGenerator : public CodeGenerator { |
public: |
- JavaGenerator(); |
- ~JavaGenerator(); |
+ JavaNanoGenerator(); |
+ ~JavaNanoGenerator(); |
// implements CodeGenerator ---------------------------------------- |
bool Generate(const FileDescriptor* file, |
const string& parameter, |
- GeneratorContext* context, |
+ GeneratorContext* output_directory, |
string* error) const; |
private: |
- GOOGLE_DISALLOW_EVIL_CONSTRUCTORS(JavaGenerator); |
+ GOOGLE_DISALLOW_EVIL_CONSTRUCTORS(JavaNanoGenerator); |
}; |
-} // namespace java |
+} // namespace javanano |
} // namespace compiler |
} // namespace protobuf |
} // namespace google |
-#endif // GOOGLE_PROTOBUF_COMPILER_JAVA_GENERATOR_H__ |
+#endif // GOOGLE_PROTOBUF_COMPILER_JAVANANO_NANO_GENERATOR_H__ |
@@ -32,10 +32,10 @@ |
// Sanjay Ghemawat, Jeff Dean, and others. |
// |
-// Generates Java code for a given .proto file. |
+// Generates Java nano code for a given .proto file. |
-#ifndef GOOGLE_PROTOBUF_COMPILER_JAVA_GENERATOR_H__ |
-#define GOOGLE_PROTOBUF_COMPILER_JAVA_GENERATOR_H__ |
+#ifndef GOOGLE_PROTOBUF_COMPILER_JAVANANO_NANO_GENERATOR_H__ |
+#define GOOGLE_PROTOBUF_COMPILER_JAVANANO_NANO_GENERATOR_H__ |
#include <string> |
#include <google/protobuf/compiler/code_generator.h> |